summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/upd934g.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/upd934g.cpp')
-rw-r--r--src/devices/sound/upd934g.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/sound/upd934g.cpp b/src/devices/sound/upd934g.cpp
index 75ba3fb4186..fecb6fc8a18 100644
--- a/src/devices/sound/upd934g.cpp
+++ b/src/devices/sound/upd934g.cpp
@@ -49,7 +49,7 @@ upd934g_device::upd934g_device(const machine_config &mconfig, const char *tag, d
void upd934g_device::device_start()
{
// create sound stream
- m_stream = machine().sound().stream_alloc(*this, 0, 4, 20000);
+ m_stream = stream_alloc_legacy(0, 4, 20000);
// resolve callbacks
m_data_cb.resolve_safe(0);
@@ -81,11 +81,11 @@ void upd934g_device::device_reset()
}
//-------------------------------------------------
// sound_stream_update - handle update requests for
// our sound stream
//-------------------------------------------------
-void upd934g_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void upd934g_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
for (unsigned ch = 0; ch < 4; ch++)
{
@@ -81,11 +81,11 @@ void upd934g_device::device_reset()
}
//-------------------------------------------------
-// sound_stream_update - handle update requests for
+// sound_stream_update_legacy - handle update requests for
// our sound stream
//-------------------------------------------------